@@ -447,7 +447,7 @@ class Environment(object):
             # prepend brew for global installs
             manifest = self.target or self.source
             if self.system.isOSX() and manifest.is_affirmative('config', 'use_global_packagemanagers'):
-                self.directory.add_to_env('sprinter_prepend_path "%s" PATH' % '/usr/local/bin/')
+                self.directory.add_to_env('sprinter_prepend_path "%s" PATH' % '/usr/local/bin')
             self.directory.add_to_env('sprinter_prepend_path "%s" PATH' % self.directory.bin_path())
             self.directory.add_to_env('sprinter_prepend_path "%s" LIBRARY_PATH' % self.directory.lib_path())
             self.directory.add_to_env('sprinter_prepend_path "%s" C_INCLUDE_PATH' % self.directory.include_path())
@@ -538,6 +538,7 @@ class Environment(object):
                     self._error_dict[feature] += result
             if len(self._error_dict[feature]) > 0:
                 self.error_occured = True
+        # catch a generic exception within a feature
         except Exception:
             e = sys.exc_info()[1]
             self.logger.info("An exception occurred with action %s in feature %s!" %
