@@ -3,6 +3,8 @@ Runs a command
 [ssh]
 formula = sprinter.formula.command
 hideoutput=true
+fail_on_error=true
+shell = False
 install=echo 'setting up...'
 update=echo 'updating...'
 remove=echo 'destroying...'
@@ -13,10 +15,12 @@ from __future__ import unicode_literals
 from sprinter.formulabase import FormulaBase
 import sprinter.lib as lib
 
+class CommandFormulaException(Exception):
+    pass
 
 class CommandFormula(FormulaBase):
 
-    valid_options = FormulaBase.valid_options + ['install', 'update', 'remove', 'activate', 'deactivate']
+    valid_options = FormulaBase.valid_options + ['install', 'update', 'remove', 'activate', 'deactivate', 'fail_on_error', 'shell']
 
     def install(self):
         self.__run_command('install', 'target')
@@ -44,4 +48,6 @@ class CommandFormula(FormulaBase):
             command = config.get(command_type)
             self.logger.debug("Running %s..." % command)
             shell = config.has('shell') and config.is_affirmative('shell')
-            lib.call(command, shell=shell)
+            return_code, output = lib.call(command, shell=shell)
+            if config.is_affirmative('fail_on_error', True) and return_code != 0:
+                raise CommandFormulaException("Command returned a return code of {0}!".format(return_code))
