@@ -76,8 +76,8 @@ def call(command, stdin=None, stdout=PIPE, env=os.environ, cwd=None, shell=False
         output = process.communicate(input=stdin)[0]
         if output is not None:
             try:
-                logger.log(output_log_level, str(output).encode('utf-8'))
-            except UnicodeDecodeError: 
+                logger.log(output_log_level, output.decode('utf-8'))
+            except UnicodeDecodeError:
                 pass
         return (process.returncode, output)
     except OSError:
